Module: MethodChainable
- Included in:
- Example
- Defined in:
- lib/method_chainable.rb,
lib/method_chainable/proxy.rb,
lib/method_chainable/version.rb
Defined Under Namespace
Classes: Proxy
Constant Summary collapse
- VERSION =
"1.0.1"
Instance Method Summary collapse
-
#chain(input = nil) ⇒ Object
Returns a Proxy object which intercepts method calls using method missing.
Instance Method Details
#chain(input = nil) ⇒ Object
Returns a Proxy object which intercepts method calls using method missing
8 9 10 |
# File 'lib/method_chainable.rb', line 8 def chain(input=nil) MethodChainable::Proxy.new(self, input) end |